﻿using System.Linq;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System.Drawing;

namespace WG_FixedCellBorder
{
    internal class CustomDrawFilter : IUIElementDrawFilter
    {
        private UltraGrid grid = null;

        public CustomDrawFilter(UltraGrid grid)
        {
            this.grid = grid;
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            var fixedLine = drawParams.Element.GetDescendant(typeof(FixedCellSeparatorUIElement)) as FixedCellSeparatorUIElement;

            if (fixedLine != null)
            {
                var color = grid.DisplayLayout.Override.FixedCellSeparatorColor;

                var rowElements = drawParams.Element.ChildElements.OfType<RowUIElement>().OrderBy(el => el.Rect.Y).ToList();

                var top = rowElements[0].GetDescendant(typeof(CellUIElement)).Rect.Top;
                var bottom = rowElements[rowElements.Count -1].GetDescendant(typeof(CellUIElement)).Rect.Bottom;
                var x = fixedLine.Rect.X;

                using (Pen p = new Pen(color))
                {
                    drawParams.Graphics.DrawLine(p, new Point(x, top), new Point(x, bottom));
                }

            }

            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is RowColRegionIntersectionUIElement)
            {
                return DrawPhase.AfterDrawChildElements;
            }
            return DrawPhase.None;
        }
    }
}